# Phronesitron

Phronesitron is a set of tools to interact with textual AI
tools like OpenAI's models.

Example use:

```
> ph what is the metaphysical meaning of a slinky
The metaphysical meaning of a slinky can be interpreted in several
ways. On one level, it can represent the interconnectedness of all
things, with its seemingly endless loops of energy and motion. It can
also be seen as a symbol of resilience and adaptability, as it can be
stretched and bent without breaking. Finally, it can be seen as a
metaphor for the impermanence of life, with its ever-changing shapes
and movements.
```

Currently, openAI models are supported, 


# Setup

Set the openAI API key (get it from here: https://platform.openai.com/account/api-keys)

```
export OPENAIKEY=<put key here>
```

# Versioning

Uses semantic versioning. https://semver.org/

